@@ -22,7 +22,8 @@ class gNMIclient(object):
     This class instantiates the object, which interacts with the network elements over gNMI.
     """
     def __init__(self, target: tuple, username: str = None, password: str = None, 
-                 debug: bool = False, insecure: bool = False, path_cert: str = None, override: str = None):
+                 debug: bool = False, insecure: bool = False, path_cert: str = None, override: str = None,
+                 gnmi_timeout: int = 5):
         """
         Initializing the object
         """
@@ -31,8 +32,7 @@ class gNMIclient(object):
         self.__debug = debug
         self.__insecure = insecure
         self.__path_cert = path_cert
-        self.__override = override
-        self.__options=[('grpc.ssl_target_name_override', self.__override)]
+        self.__options=[('grpc.ssl_target_name_override', override)] if override else None
 
         if re.match('.*:.*', target[0]):
             self.__target = (f'[{target[0]}]', target[1])
@@ -47,7 +47,7 @@ class gNMIclient(object):
 
         if self.__insecure:
             self.__channel = grpc.insecure_channel(f'{self.__target[0]}:{self.__target[1]}', self.__metadata)
-            grpc.channel_ready_future(self.__channel).result(timeout=5)
+            grpc.channel_ready_future(self.__channel).result(timeout=gnmi_timeout)
             self.__stub = gNMIStub(self.__channel)
 
         else:
@@ -60,8 +60,9 @@ class gNMIclient(object):
                     logging.error('The SSL certificate cannot be opened.')
                     sys.exit(10)
 
-            self.__channel = grpc.secure_channel(f'{self.__target[0]}:{self.__target[1]}', cert, self.__options)
-            grpc.channel_ready_future(self.__channel).result(timeout=5)
+            self.__channel = grpc.secure_channel(f'{self.__target[0]}:{self.__target[1]}', 
+                                                 credentials=cert, options=self.__options)
+            grpc.channel_ready_future(self.__channel).result(timeout=gnmi_timeout)
             self.__stub = gNMIStub(self.__channel)
 
         return self
@@ -76,12 +77,16 @@ class gNMIclient(object):
 
         try:
             gnmi_message_request = CapabilityRequest()
-            gnmi_message_response = self.__stub.Capabilities(gnmi_message_request, metadata=self.__metadata)
 
             if self.__debug:
                 print("gNMI request:\n------------------------------------------------")
                 print(gnmi_message_request)
-                print("------------------------------------------------\n\n\ngNMI response:\n------------------------------------------------")
+                print("------------------------------------------------")
+
+            gnmi_message_response = self.__stub.Capabilities(gnmi_message_request, metadata=self.__metadata)
+
+            if self.__debug:
+                print("\n\n\ngNMI response:\n------------------------------------------------")
                 print(gnmi_message_response)
                 print("------------------------------------------------")
 
@@ -199,12 +204,16 @@ class gNMIclient(object):
 
         try:
             gnmi_message_request = GetRequest(path=protobuf_paths, type=pb_datatype, encoding=pb_encoding)
-            gnmi_message_response = self.__stub.Get(gnmi_message_request, metadata=self.__metadata)
 
             if self.__debug:
                 print("gNMI request:\n------------------------------------------------")
                 print(gnmi_message_request)
-                print("------------------------------------------------\n\n\ngNMI response:\n------------------------------------------------")
+                print("------------------------------------------------")
+
+            gnmi_message_response = self.__stub.Get(gnmi_message_request, metadata=self.__metadata)
+
+            if self.__debug:
+                print("\n\n\ngNMI response:\n------------------------------------------------")
                 print(gnmi_message_response)
                 print("------------------------------------------------")
 
@@ -375,12 +384,16 @@ class gNMIclient(object):
 
         try:
             gnmi_message_request = SetRequest(delete=del_protobuf_paths, update=update_msg, replace=replace_msg)
-            gnmi_message_response = self.__stub.Set(gnmi_message_request, metadata=self.__metadata)
 
             if self.__debug:
                 print("gNMI request:\n------------------------------------------------")
                 print(gnmi_message_request)
-                print("------------------------------------------------\n\n\ngNMI response:\n------------------------------------------------")
+                print("------------------------------------------------")
+
+            gnmi_message_response = self.__stub.Set(gnmi_message_request, metadata=self.__metadata)
+
+            if self.__debug:
+                print("\n\n\ngNMI response:\n------------------------------------------------")
                 print(gnmi_message_response)
                 print("------------------------------------------------")
 
